@@ -23,64 +23,56 @@ from aliyunsdkdypnsapi.endpoint import endpoint_data
 class CreateVerifySchemeRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dypnsapi', '2017-05-25', 'CreateVerifyScheme','dypns')
+		RpcRequest.__init__(self, 'Dypnsapi', '2017-05-25', 'CreateVerifyScheme')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_BundleId(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_BundleId(self): # String
 		return self.get_query_params().get('BundleId')
 
-	def set_BundleId(self,BundleId):
-		self.add_query_param('BundleId',BundleId)
-
-	def get_AppName(self):
+	def set_BundleId(self, BundleId):  # String
+		self.add_query_param('BundleId', BundleId)
+	def get_AppName(self): # String
 		return self.get_query_params().get('AppName')
 
-	def set_AppName(self,AppName):
-		self.add_query_param('AppName',AppName)
-
-	def get_PackSign(self):
+	def set_AppName(self, AppName):  # String
+		self.add_query_param('AppName', AppName)
+	def get_PackSign(self): # String
 		return self.get_query_params().get('PackSign')
 
-	def set_PackSign(self,PackSign):
-		self.add_query_param('PackSign',PackSign)
-
-	def get_PackName(self):
+	def set_PackSign(self, PackSign):  # String
+		self.add_query_param('PackSign', PackSign)
+	def get_PackName(self): # String
 		return self.get_query_params().get('PackName')
 
-	def set_PackName(self,PackName):
-		self.add_query_param('PackName',PackName)
-
-	def get_ResourceOwnerAccount(self):
+	def set_PackName(self, PackName):  # String
+		self.add_query_param('PackName', PackName)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OsType(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OsType(self): # String
 		return self.get_query_params().get('OsType')
 
-	def set_OsType(self,OsType):
-		self.add_query_param('OsType',OsType)
-
-	def get_OwnerId(self):
+	def set_OsType(self, OsType):  # String
+		self.add_query_param('OsType', OsType)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_SchemeName(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_SchemeName(self): # String
 		return self.get_query_params().get('SchemeName')
 
-	def set_SchemeName(self,SchemeName):
-		self.add_query_param('SchemeName',SchemeName)
\ No newline at end of file
+	def set_SchemeName(self, SchemeName):  # String
+		self.add_query_param('SchemeName', SchemeName)
